@@ -6,7 +6,7 @@ Lingua::EN::Fathom - Measure readability of English text
 
     use Lingua::EN::Fathom;
 
-    my $text = new Lingua::EN::Fathom;
+    my $text = Lingua::EN::Fathom->new();
 
     $text->analyse_file("sample.txt");
 
@@ -65,7 +65,7 @@ The C<new> method creates an instance of an text object This must be called
 before any of the following methods are invoked. Note that the object only
 needs to be created once, and can be reused with new input data.
 
-   my $text = new Lingua::EN::Fathom;
+   my $text = Lingua::EN::Fathom->new();
 
 =head2 analyse_file
 
@@ -252,11 +252,10 @@ Lingua::EN::Fathom was written by Kim Ryan <kimryan at cpan dot org>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007 Kim Ryan. All rights reserved.
+Copyright (c) 2015 Kim Ryan. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
-at your option, any later version of Perl 5 you may have available.
+it under the same terms as Perl itself.
 
 =cut
 
@@ -268,7 +267,7 @@ use Lingua::EN::Syllable;
 use strict;
 use warnings;
 
-our $VERSION = '1.12';
+our $VERSION = '1.18';
 
 #------------------------------------------------------------------------------
 # Create a new instance of a text object.
